==> PXG2_v1.1.17.tar.gz: pxg2/apps/php/wwwroot/index.php <==
<?php
    // @used
  include 'auth_trangosys.php';
    flush();
  import_page_header();
  display_logo_banner();
  echo '<body class="vernav" onload="getRemoteLocalStatistics()">';
  echo '<div id="loading">
  <img id="loading-image" src="images/loading.gif" alt="Loading..." /></div>';

  display_test_menu_status(1);
  display_list_status();

  if($v3_en == 1)
  {
  	$ret = snmp3_get($localhost, $user, $sec_level, $auth_protocol, $auth_pass, $priv_protocol, $priv_pass, $link_lock_oid);
  	$local_link = preg_replace("/(INTEGER:)/", "", $ret);

  	$ret = snmp3_get($localhost, $user, $sec_level, $auth_protocol, $auth_pass, $priv_protocol, $priv_pass, $remote_link_oid);
  	$remote_link = preg_replace("/(INTEGER:)/", "", $ret);

  	/*if(($local_link == 1) && ($remote_link == 1))
  	{
      	  $set = snmp3_set($localhost, $user, $sec_level, $auth_protocol, $auth_pass, $priv_protocol, $priv_pass, $remote_req_oid, "i", 8, 5000000, 0);
      	  usleep(1000000);
  	}*/
  }
  else
  {
  	$ret = snmpget($localhost, $read_str, $link_lock_oid);
  	$local_link = preg_replace("/(INTEGER:)/", "", $ret);

  	$ret = snmpget($localhost, $read_str, $remote_link_oid);
  	$remote_link = preg_replace("/(INTEGER:)/", "", $ret);

  	/*if(($local_link == 1) && ($remote_link == 1))
  	{
      	  $set = snmpset($localhost, $write_str, $remote_req_oid, "i", 8, 5000000, 0);
      	  usleep(1000000);
  	}*/
  }
  
  $rfmCount = CustomDataRetrieval::getRFMCount();
  display_content_table_no_border();
  echo '<tr height="10">';

  display_none_shaded_row();
  display_subtitle("SYSTEM > SYSTEM INFO");
  echo '<td width="30%"></td>';
  enclose_content_table_row();

  display_none_shaded_row();
  echo '<td></td>';
  display_page_subtitle("Local Side");
  display_page_subtitle("Remote Side");
  enclose_content_table_row();

  display_none_shaded_row();
  display_center_parameter_name("System Uptime:");
  display_system_uptime();
  echo '<td rowspan="20"><div class="data-cgi">';
  if(($local_link == 1) && ($remote_link == 1))
    //echo CustomUI::hackDisplayRFLinkCGIForLinkPosition(exec("/var/www/cgi-bin/rflink.cgi 6"));
    echo exec("/var/www/cgi-bin/rflink.cgi 6");
  else
    echo '<b>No remote link!</b>';
  echo '</div></td>';
  enclose_content_table_row();

  display_none_shaded_row();
  display_parameter_name("Sysconfig:");
  display_text_left($sysconfig_oid);
  enclose_content_table_row();

  display_none_shaded_row();
  display_parameter_name("Model:");
  display_text_left($omu_model_oid);
  enclose_content_table_row();

  display_none_shaded_row();
  display_parameter_name("Serial Number:");
  display_text_left($omu_serial_oid);
  enclose_content_table_row();

  display_none_shaded_row();
  display_parameter_name("RF1 Model:");
  display_text_left($odu1_model_oid);
  enclose_content_table_row();
  if ($rfmCount == 2) {
    display_none_shaded_row();
    display_parameter_name("RF2 Model:");
    display_text_left($odu2_model_oid);
    enclose_content_table_row();
  }
  display_none_shaded_row();
  display_parameter_name("RF1 Serial ID:");
  display_text_left($odu1_serial_id_oid);
  enclose_content_table_row();
  
  if ($rfmCount == 2) {
    display_none_shaded_row();
    display_parameter_name("RF2 Serial ID:");
    display_text_left($odu2_serial_id_oid);
    enclose_content_table_row();
  }
  display_none_shaded_row();
  display_center_parameter_name("MAC Address:");
  display_text_left($mac_eth1_oid);
  enclose_content_table_row();

  display_none_shaded_row();
  display_parameter_name("System Temp (deg C):");
  display_text_left($idu_temp_oid);
  enclose_content_table_row();

  display_none_shaded_row();
  display_parameter_name("RF1 Temp (deg C):");
  display_parameter_name(CustomDataRetrieval::pullSysRFODUTemp(1));
  enclose_content_table_row();
  
  if ($rfmCount == 2) {
    display_none_shaded_row();
    display_parameter_name("RF2 Temp (deg C):");
    display_parameter_name(CustomDataRetrieval::pullSysRFODUTemp(2));
    enclose_content_table_row();
  }

  display_none_shaded_row();
  display_parameter_name("Azimuth (degree):");
  display_text_position($azimuth_oid, $left);
  enclose_content_table_row();

display_none_shaded_row();
display_parameter_name("Downtilt (degree):");
display_parameter_name(CustomDataRetrieval::pullSysDowntilt());
enclose_content_table_row();

  display_none_shaded_row();
  display_parameter_name("Level (degree):");
  display_text_position($level_oid, $left);
  enclose_content_table_row();

  display_none_shaded_row();
  display_parameter_name("Input Voltage (VDC):");
  display_text_position($voltage48_oid, $left);
  enclose_content_table_row();

  display_none_shaded_row();
  display_parameter_name("Total Current (Amps):");
  display_parameter_name(CustomDataRetrieval::pullSysSumCurrentConsumption());
  enclose_content_table_row();

  display_none_shaded_row();
  display_parameter_name("Humidity (%):");
  display_text_position($humidity_oid, $left);
  enclose_content_table_row();
  
  display_none_shaded_row();
  display_parameter_name("Link Position:");
  display_text_left($link_position_oid);
  enclose_content_table_row();
  
  //display_none_shaded_row();
  //display_parameter_name("Date-Time:");
  //display_date();
  //enclose_content_table_row();

  enclose_content_table();
  display_footer();

?>
<script language="javascript" type="text/javascript">
     $(window).load(function() {
     $('#loading').hide();
  });
</script>
<script language="javascript" type="text/javascript">
     window.onbeforeunload = function() {
     $('#loading').show();
  };
</script>

==> PXG2_v1.1.20.tar.gz: pxg2/apps/php/wwwroot/index.php <==
<?php
    // @used
  include 'auth_trangosys.php';
    flush();
  import_page_header();
  display_logo_banner();
  echo '<body class="vernav" onload="getRemoteLocalStatistics()">';
  echo '<div id="loading">
  <img id="loading-image" src="images/loading.gif" alt="Loading..." /></div>';

  display_test_menu_status(1);
  display_list_status();

  if($v3_en == 1)
  {
  	$ret = snmp3_get($localhost, $user, $sec_level, $auth_protocol, $auth_pass, $priv_protocol, $priv_pass, $link_lock_oid);
  	$local_link = preg_replace("/(INTEGER:)/", "", $ret);

  	$ret = snmp3_get($localhost, $user, $sec_level, $auth_protocol, $auth_pass, $priv_protocol, $priv_pass, $remote_link_oid);
  	$remote_link = preg_replace("/(INTEGER:)/", "", $ret);

  	/*if(($local_link == 1) && ($remote_link == 1))
  	{
      	  $set = snmp3_set($localhost, $user, $sec_level, $auth_protocol, $auth_pass, $priv_protocol, $priv_pass, $remote_req_oid, "i", 8, 5000000, 0);
      	  usleep(1000000);
  	}*/
  }
  else
  {
  	$ret = snmpget($localhost, $read_str, $link_lock_oid);
  	$local_link = preg_replace("/(INTEGER:)/", "", $ret);

  	$ret = snmpget($localhost, $read_str, $remote_link_oid);
  	$remote_link = preg_replace("/(INTEGER:)/", "", $ret);

  	/*if(($local_link == 1) && ($remote_link == 1))
  	{
      	  $set = snmpset($localhost, $write_str, $remote_req_oid, "i", 8, 5000000, 0);
      	  usleep(1000000);
  	}*/
  }
  
  // model name recognition
  $odu1_is_powered = false;
  $odu2_is_powered = false;
  $odu1_model_name = CustomDataRetrieval::pullSysOID(OID_Mappings::$odu1_model);
  $odu2_model_name = "N/A";
  $odu1_is_detected = true;
  $odu2_is_detected = true;
  $rfmCount =	CustomDataRetrieval::getRFMCount();
  $sysconfig = CustomDataRetrieval::pullSysOID($sysconfig_oid);
  $is_rf2_virtual = ($rfmCount == 2) && ($sysconfig == 6 || $sysconfig == 7);  // 2+0 sp, half xpic sp
  
  $odu1_is_powered = CustomDataRetrieval::pullSysODUIsPowered(1);
  if ($is_rf2_virtual){
    $odu2_is_powered = $odu1_is_powered;
    $odu2_model_name = $odu1_model_name;
  }
  else if ($rfmCount == 2){
    $odu2_is_powered = CustomDataRetrieval::pullSysODUIsPowered(2);
    $odu2_model_name = CustomDataRetrieval::pullSysOID(OID_Mappings::$odu2_model);
  }
  else{
    $odu2_is_powered = false;
  }
  
  if (!$odu1_is_powered || empty($odu1_model_name) || $odu1_model_name === "N/A" ) {
    $odu1_is_detected = false;
  }
  
  if($is_rf2_virtual){
    $odu2_is_detected = $odu1_is_detected;
  }
  else if ($rfmCount == 2 && (!$odu2_is_powered || empty($odu2_model_name) || $odu2_model_name === "N/A")){
    $odu2_is_detected = false;
  }
  
  
  $rfmCount = CustomDataRetrieval::getRFMCount();
  display_content_table_no_border();
  echo '<tr height="10">';

  display_none_shaded_row();
  display_subtitle("SYSTEM > SYSTEM INFO");
  echo '<td width="30%"></td>';
  enclose_content_table_row();

  display_none_shaded_row();
  echo '<td></td>';
  display_page_subtitle("Local Side");
  display_page_subtitle("Remote Side");
  enclose_content_table_row();

  display_none_shaded_row();
  display_center_parameter_name("System Uptime:");
  display_system_uptime();
  echo '<td rowspan="20"><div class="data-cgi">';
  if(($local_link == 1) && ($remote_link == 1))
    //echo CustomUI::hackDisplayRFLinkCGIForLinkPosition(exec("/var/www/cgi-bin/rflink.cgi 6"));
    echo exec("/var/www/cgi-bin/rflink.cgi 6");
  else
    echo '<b>No remote link!</b>';
  echo '</div></td>';
  enclose_content_table_row();

  display_none_shaded_row();
  display_parameter_name("Sysconfig:");
  display_text_left($sysconfig_oid);
  enclose_content_table_row();

  display_none_shaded_row();
  display_parameter_name("Model:");
  display_text_left($omu_model_oid);
  enclose_content_table_row();

  display_none_shaded_row();
  display_parameter_name("Serial Number:");
  display_text_left($omu_serial_oid);
  enclose_content_table_row();
  
  display_none_shaded_row();
  display_parameter_name("RF1 Model:");
  ($odu1_is_powered && $odu1_is_detected)?display_text_left(OID_Mappings::$odu1_model):display_left_label("-");
  enclose_content_table_row();
  
  if ($rfmCount == 2) {
    display_none_shaded_row();
    display_parameter_name("RF2 Model:");
    if ($is_rf2_virtual) {
      ($odu1_is_powered && $odu1_is_detected)?display_text_left(OID_Mappings::$odu1_model):display_left_label("-");
    }
    else{
      ($odu2_is_powered && $odu2_is_detected)?display_text_left(OID_Mappings::$odu2_model):display_left_label("-");
    }
    enclose_content_table_row();
  }
  display_none_shaded_row();
  display_parameter_name("RF1 Serial ID:");
  display_text_left($odu1_serial_id_oid);
  enclose_content_table_row();
  
  if ($rfmCount == 2) {
    display_none_shaded_row();
    display_parameter_name("RF2 Serial ID:");
    display_text_left($odu2_serial_id_oid);
    enclose_content_table_row();
  }
  display_none_shaded_row();
  display_center_parameter_name("MAC Address:");
  display_text_left($mac_eth1_oid);
  enclose_content_table_row();

  display_none_shaded_row();
  display_parameter_name("System Temp (deg C):");
  display_text_left($idu_temp_oid);
  enclose_content_table_row();

  display_none_shaded_row();
  display_parameter_name("RF1 Temp (deg C):");
  display_parameter_name(CustomDataRetrieval::pullSysRFODUTemp(1));
  enclose_content_table_row();
  
  if ($rfmCount == 2) {
    display_none_shaded_row();
    display_parameter_name("RF2 Temp (deg C):");
    display_parameter_name(CustomDataRetrieval::pullSysRFODUTemp(2));
    enclose_content_table_row();
  }

  display_none_shaded_row();
  display_parameter_name("Azimuth (degree):");
  display_text_position($azimuth_oid, $left);
  enclose_content_table_row();

display_none_shaded_row();
display_parameter_name("Downtilt (degree):");
display_parameter_name(CustomDataRetrieval::pullSysDowntilt());
enclose_content_table_row();

  display_none_shaded_row();
  display_parameter_name("Level (degree):");
  display_text_position($level_oid, $left);
  enclose_content_table_row();

  display_none_shaded_row();
  display_parameter_name("Input Voltage (VDC):");
  display_text_position($voltage48_oid, $left);
  enclose_content_table_row();

  display_none_shaded_row();
  display_parameter_name("Total Current (Amps):");
  display_parameter_name(CustomDataRetrieval::pullSysSumCurrentConsumption());
  enclose_content_table_row();

  display_none_shaded_row();
  display_parameter_name("Humidity (%):");
  display_text_position($humidity_oid, $left);
  enclose_content_table_row();
  
  display_none_shaded_row();
  display_parameter_name("Link Position:");
  display_text_left($link_position_oid);
  enclose_content_table_row();
  
  //display_none_shaded_row();
  //display_parameter_name("Date-Time:");
  //display_date();
  //enclose_content_table_row();

  enclose_content_table();
  display_footer();

?>
<script language="javascript" type="text/javascript">
     $(window).load(function() {
     $('#loading').hide();
  });
</script>
<script language="javascript" type="text/javascript">
     window.onbeforeunload = function() {
     $('#loading').show();
  };
</script>
